summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 14:18:56 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 14:18:56 +0900
commit255de04fbbb4597e46fb25017879a6afeaf4cebd (patch)
treef9a534a4028d77291afb56a32210c6e7cc95c759
parentbb5b733cc00a3fa0882302fb5411ba2191a1a754 (diff)
downloadtdevelop-255de04f.tar.gz
tdevelop-255de04f.zip
qt -> tqt conversion:
qtlib -> tqtlib libqt -> libtqt QTLIB -> TQTLIB LIBQT -> LIBTQT Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
-rw-r--r--parts/appwizard/common/scons/admin/kde.py18
-rw-r--r--tdevelop.m4.in2
2 files changed, 10 insertions, 10 deletions
diff --git a/tdevelop.m4.in b/tdevelop.m4.in
index 160c938a..36e584da 100644
--- a/tdevelop.m4.in
+++ b/tdevelop.m4.in
@@ -404,7 +404,7 @@ ac_db_lib=db
save_LDFLAGS="$LDFLAGS"
CXXFLAGS="$CXXFLAGS $TQT_INCLUDES $ac_db_includedir $ac_db_libdir -l$ac_db_lib"
- LDFLAGS="$LDFLAGS $LIBQT"
+ LDFLAGS="$LDFLAGS $LIBTQT"
AC_TRY_LINK([
#include <db.h>
diff --git a/parts/appwizard/common/scons/admin/kde.py b/parts/appwizard/common/scons/admin/kde.py
index e9f94d57..aa275dab 100644
--- a/parts/appwizard/common/scons/admin/kde.py
+++ b/parts/appwizard/common/scons/admin/kde.py
@@ -37,7 +37,7 @@ def detect_kde(env):
kdeincludes = env['ARGS'].get('kdeincludes', None)
tdelibs = env['ARGS'].get('tdelibs', None)
qtincludes = env['ARGS'].get('qtincludes', None)
- qtlibs = env['ARGS'].get('qtlibs', None)
+ tqtlibs = env['ARGS'].get('tqtlibs', None)
if libdir:
libdir = libdir+libsuffix
@@ -71,7 +71,7 @@ def detect_kde(env):
else:
libdir = os.popen('tde-config --expandvars --install lib').read().strip()
libtdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libtdeui.la')
- m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libqt').read().strip().split()[2])
+ m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libtqt').read().strip().split()[2])
if m:
qtdir = m.group(1)
print YELLOW+"qt was found as "+m.group(1)+NORMAL
@@ -199,9 +199,9 @@ def detect_kde(env):
## qt libs and includes
env['QTINCLUDEPATH']=qtincludes
- if not qtlibs:
- qtlibs=qtdir+"/lib"
- env['QTLIBPATH']=qtlibs
+ if not tqtlibs:
+ tqtlibs=qtdir+"/lib"
+ env['TQTLIBPATH']=tqtlibs
def generate(env):
""""Set up the qt and kde environment and builders - the moc part is difficult to understand """
@@ -217,7 +217,7 @@ def generate(env):
"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/tde on debian, ...)
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
"""+BOLD+"""* tdelibs """+NORMAL+""": path to the kde libs, for linking the programs
"""+BOLD+"""* qtlibs """+NORMAL+""": same punishment, for qt libraries
ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
"""+NORMAL
@@ -366,7 +366,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
('PREFIX', 'root of the program installation'),
('QTDIR', 'root of qt directory'),
- ('QTLIBPATH', 'path to the qt libraries'),
+ ('TQTLIBPATH', 'path to the qt libraries'),
('QTINCLUDEPATH', 'path to the qt includes'),
('QT_UIC', 'moc directory'),
('QT_MOC', 'moc executable command'),
@@ -400,7 +400,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
## set default variables, one can override them in sconscript files
env.Append(CXXFLAGS = ['-I'+env['KDEINCLUDEPATH'], '-I'+env['QTINCLUDEPATH'] ])
- env.Append(LIBPATH = [env['KDELIBPATH'], env['QTLIBPATH'] ])
+ env.Append(LIBPATH = [env['KDELIBPATH'], env['TQTLIBPATH'] ])
env['STATIC_AND_SHARED_OBJECTS_ARE_THE_SAME'] = 1
@@ -823,7 +823,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
lenv.Append( CPPFLAGS = '-DQT_NO_TRANSLATION' )
if 'rpath' in _flags:
## Use this to set rpath - this may cause trouble if folders are moved (chrpath)
- lenv.Append( RPATH = [env['QTLIBPATH'], env['KDELIBPATH'], env['KDEMODULE']] )
+ lenv.Append( RPATH = [env['TQTLIBPATH'], env['KDELIBPATH'], env['KDEMODULE']] )
if 'thread' in _flags:
## Uncomment the following if you need threading support
lenv.KDEaddflags_cxx( ['-DTQT_THREAD_SUPPORT', '-D_REENTRANT'] )
@@ -217,7 +217,7 @@ def generate(env):
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
"""+BOLD+"""* tdelibs """+NORMAL+""": path to the kde libs, for linking the programs
-"""+BOLD+"""* qtlibs """+NORMAL+""": same punishment, for qt libraries
+"""+BOLD+"""* tqtlibs """+NORMAL+""": same punishment, for qt libraries
ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
"""+NORMAL